"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var material_1 = require("@angular/material");
var core_2 = require("@tangential/core");
var input_config_1 = require("../../input-config");
//noinspection TypeScriptPreferShortImport
var choose_input_widget_dialog_1 = require("../choose-input-widget-dialog/choose-input-widget-dialog");
var input_types_registry_1 = require("../input-types-registry");
var input_view_mode_1 = require("../input-view-mode");
var EditConfigurableWidgetComponent = (function () {
    function EditConfigurableWidgetComponent(inputRegistry, changeDetectorRef, dialog) {
        this.inputRegistry = inputRegistry;
        this.changeDetectorRef = changeDetectorRef;
        this.dialog = dialog;
        this.inputConfigChange = new core_1.EventEmitter(false);
        this.inputNames = [];
    }
    EditConfigurableWidgetComponent.prototype.ngOnInit = function () {
        this.inputNames = this.inputRegistry.inputNames;
        if (this.inputConfig) {
            this.updateInputConfig(this.inputConfig);
        }
    };
    EditConfigurableWidgetComponent.prototype.ngOnChanges = function (changes) {
        if (changes.inputConfig) {
            this.updateInputConfig(this.inputConfig);
        }
    };
    EditConfigurableWidgetComponent.prototype.inputWidgetChange = function (newConfig) {
        var inputName = newConfig._inputName;
        if (!this.inputConfig || inputName !== this.inputConfig._inputName) {
            var inputEntrySet = this.inputRegistry.getInputSet(inputName);
            var base = newConfig.toJson(true);
            if (this.inputConfig) {
                base.label = this.inputConfig.label !== this.inputConfig.getModel().label
                    ? this.inputConfig.label
                    : null;
                base.orderIndex = this.inputConfig.orderIndex;
            }
            var newInputConfig = inputEntrySet.createInputConfig(base);
            newInputConfig._inputName = inputName;
            this.updateInputConfig(newInputConfig);
            this.inputConfigChange.emit(this.inputConfig);
        }
    };
    EditConfigurableWidgetComponent.prototype.updateInputConfig = function (inputConfig) {
        this.inputConfig = inputConfig;
        var inputValue = inputConfig.typeConfig.createValue();
        this.inputTemplate = this.inputRegistry.createTemplateForType(inputConfig, input_view_mode_1.InputViewModes.CONFIGURE, inputValue);
        core_2.Hacks.materialDesignPlaceholderText(this.changeDetectorRef);
    };
    EditConfigurableWidgetComponent.prototype.canChangeWidget = function () {
        return !this.inputConfig.$isSystem;
    };
    EditConfigurableWidgetComponent.prototype.showChooseInputDialog = function () {
        var _this = this;
        var dialogRef = this.dialog.open(choose_input_widget_dialog_1.ChooseInputWidgetDialog, {
            height: '80%',
            width: '100%',
        });
        dialogRef.afterClosed().subscribe(function (result) {
            if (result && result.config) {
                _this.inputWidgetChange(result.config);
            }
        });
    };
    EditConfigurableWidgetComponent.prototype.onTemplateChanged = function (template) {
        if (template.ival && template.ival.value !== template.config.typeConfig.defaultValue) {
            template.ival = template.config.typeConfig.createValue();
        }
    };
    return EditConfigurableWidgetComponent;
}());
__decorate([
    core_1.Input(),
    __metadata("design:type", input_config_1.InputConfig)
], EditConfigurableWidgetComponent.prototype, "inputConfig", void 0);
__decorate([
    core_1.Output(),
    __metadata("design:type", core_1.EventEmitter)
], EditConfigurableWidgetComponent.prototype, "inputConfigChange", void 0);
EditConfigurableWidgetComponent = __decorate([
    core_1.Component({
        selector: 'tanj-edit-configurable-widget',
        template: "<div flex *ngIf=\"inputConfig\" layout=\"column\" layout-align=\"space-between\"> <fieldset class=\"tanj-input-preview\" layout=\"row\" layout-align=\"start\"> <legend>Preview</legend> <tanj-input-template-container [inputConfig]=\"inputTemplate.config\" [inputIval]=\"inputTemplate.ival\" [mode]=\"'EDIT'\"></tanj-input-template-container> <div layout=\"row\" layout-align=\"end\"> <button class=\"tanj-choose-widget-button\" md-raised-button color=\"primary\" [disabled]=\"!canChangeWidget()\" (click)=\"showChooseInputDialog()\"> <tanj-icon ligature=\"edit\" label=\"Choose Widget\" i18n-label></tanj-icon> </button> </div> </fieldset> <div flex class=\"tanj-inputs-configuration-container\" layout=\"column\" layout-align=\"start\"> <div flex=\"70\" *ngIf=\"inputTemplate\" class=\"tanj-input-configuration-inner\" layout=\"column\" layout-align=\"start\"> <div layout=\"row\" layout-align=\"start start\"> <tanj-input-template-container flex [inputConfig]=\"inputTemplate.config\" [inputIval]=\"inputTemplate.ival\" [mode]=\"inputTemplate.mode\" (change)=\"onTemplateChanged(inputTemplate)\"></tanj-input-template-container> </div> </div> </div> </div> ",
        encapsulation: core_1.ViewEncapsulation.None,
        changeDetection: core_1.ChangeDetectionStrategy.Default
    }),
    __metadata("design:paramtypes", [input_types_registry_1.InputRegistry,
        core_1.ChangeDetectorRef,
        material_1.MdDialog])
], EditConfigurableWidgetComponent);
exports.EditConfigurableWidgetComponent = EditConfigurableWidgetComponent;

//# sourceMappingURL=edit-configurable-widget.component.js.map
